@@ -4,6 +4,7 @@ from redis import Redis
 from typing import Callable, Dict, Union, List
 from celery import Celery, Task
 from celery.result import AsyncResult
+from .common.exceptions import BizException
 from .common.utils import obj_to_ref, singleton
 from .common.keys import get_result_key
 from .common.model import Callback
@@ -11,8 +12,12 @@ from .common.model import Callback
 LOGGER = logging.getLogger(__name__)
 
 
-@singleton
+# @singleton
 class CeleryClient(object):
+    """
+    Celery服务客户端
+    注意：此类不建议手动初始化，可通过CeleryClientHolder初始化，方便各service类自动获取
+    """
 
     def __init__(self, celery_broker_url: str, celery_result_backend: str, client_redis_uri: str, app_code: str):
         self.broker_url = celery_broker_url
@@ -44,7 +49,7 @@ class CeleryClient(object):
             _headers['app_code'] = _headers.get('app_code', None) or self.app_code
 
             # 异步调用
-            async_result = self._get_task(task_name).apply_async(kwargs=task_params, queue=f'task_queue.{task_name}', headers=_headers)
+            async_result = self._get_task(task_name).apply_async(kwargs=task_params, queue=f'task.{task_name}', headers=_headers)
             # 绑定回调处理函数
             self._bind_callback(task_name, async_result, callback)
             return async_result
@@ -58,7 +63,7 @@ class CeleryClient(object):
         try:
             _headers = {'app_code': self.app_code}
             # 异步调用
-            async_result = self._get_task(task_name).apply_async(kwargs=task_params, queue=f'task_queue.{task_name}', headers=_headers)
+            async_result = self._get_task(task_name).apply_async(kwargs=task_params, queue=f'task.{task_name}', headers=_headers)
             # 等待结果
             _timeout = 60
             if kwargs and kwargs.get('timeout', None):
@@ -92,7 +97,7 @@ class CeleryClient(object):
 
         return task
 
-    # 构建回调信息
+    # 构建回调对象
     def build_callback(self, callback_func: Union[str, Callable] = None, callback_data: Union[str, Dict, List] = None, app_code: str = None, tenant_code: str = None):
         callback = Callback()
         callback.app_code = app_code or self.app_code
@@ -104,3 +109,17 @@ class CeleryClient(object):
             callback.callback_func = obj_to_ref(callback_func)
 
         return callback
+
+
+class CeleryClientHolder(object):
+    __default_instance = None
+
+    @staticmethod
+    def init_default_instance(celery_broker_url: str, celery_result_backend: str, client_redis_uri: str, app_code: str):
+        CeleryClientHolder.__default_instance = CeleryClient(celery_broker_url, celery_result_backend, client_redis_uri, app_code)
+
+    @staticmethod
+    def default_instance():
+        if not CeleryClientHolder.__default_instance:
+            raise BizException(f'默认实例尚未初始化，请先初始化实例！')
+        return CeleryClientHolder.__default_instance
